@@ -6,9 +6,7 @@ from archinstall.tui.menu_item import MenuItem, MenuItemGroup
 from archinstall.tui.result import ResultType
 from archinstall.tui.types import Alignment, FrameProperties, FrameStyle, Orientation, PreviewStyle
 
-from ..args import arch_config_handler
 from ..hardware import GfxDriver, SysInfo
-from ..models.bootloader import Bootloader
 
 
 def select_kernel(preset: list[str] = []) -> list[str]:
@@ -46,74 +44,6 @@ def select_kernel(preset: list[str] = []) -> list[str]:
 			return result.get_values()
 
 
-def ask_for_bootloader(preset: Bootloader | None) -> Bootloader | None:
-	# Systemd is UEFI only
-	options = []
-	hidden_options = []
-	default = None
-	header = None
-
-	if arch_config_handler.args.skip_boot:
-		default = Bootloader.NO_BOOTLOADER
-	else:
-		hidden_options += [Bootloader.NO_BOOTLOADER]
-
-	if not SysInfo.has_uefi():
-		options += [Bootloader.Grub, Bootloader.Limine]
-		if not default:
-			default = Bootloader.Grub
-		header = tr('UEFI is not detected and some options are disabled')
-	else:
-		options += [b for b in Bootloader if b not in hidden_options]
-		if not default:
-			default = Bootloader.Systemd
-
-	items = [MenuItem(o.value, value=o) for o in options]
-	group = MenuItemGroup(items)
-	group.set_default_by_value(default)
-	group.set_focus_by_value(preset)
-
-	result = SelectMenu[Bootloader](
-		group,
-		header=header,
-		alignment=Alignment.CENTER,
-		frame=FrameProperties.min(tr('Bootloader')),
-		allow_skip=True,
-	).run()
-
-	match result.type_:
-		case ResultType.Skip:
-			return preset
-		case ResultType.Selection:
-			return result.get_value()
-		case ResultType.Reset:
-			raise ValueError('Unhandled result type')
-
-
-def ask_for_uki(preset: bool = True) -> bool:
-	prompt = tr('Would you like to use unified kernel images?') + '\n'
-
-	group = MenuItemGroup.yes_no()
-	group.set_focus_by_value(preset)
-
-	result = SelectMenu[bool](
-		group,
-		header=prompt,
-		columns=2,
-		orientation=Orientation.HORIZONTAL,
-		alignment=Alignment.CENTER,
-		allow_skip=True,
-	).run()
-
-	match result.type_:
-		case ResultType.Skip:
-			return preset
-		case ResultType.Selection:
-			return result.item() == MenuItem.yes()
-		case ResultType.Reset:
-			raise ValueError('Unhandled result type')
-
-
 def select_driver(options: list[GfxDriver] = [], preset: GfxDriver | None = None) -> GfxDriver | None:
 	"""
 	Some what convoluted function, whose job is simple.
