@@ -2,7 +2,7 @@ from .abstract_menu import AbstractMenu, AbstractSubMenu
 from .list_manager import ListManager
 
 __all__ = [
-	"AbstractMenu",
-	"AbstractSubMenu",
-	"ListManager",
+	'AbstractMenu',
+	'AbstractSubMenu',
+	'ListManager',
 ]
