@@ -822,22 +822,6 @@ class FilesystemType(Enum):
 			case _:
 				return None
 
-	@property
-	def installation_module(self) -> str | None:
-		match self:
-			case FilesystemType.Btrfs:
-				return 'btrfs'
-			case _:
-				return None
-
-	@property
-	def installation_binary(self) -> str | None:
-		match self:
-			case FilesystemType.Btrfs:
-				return '/usr/bin/btrfs'
-			case _:
-				return None
-
 	@property
 	def installation_hooks(self) -> str | None:
 		match self:
