@@ -105,9 +105,11 @@ def validate_package_list(packages: list[str]) -> tuple[list[str], list[str]]:
 
 
 def installed_package(package: str) -> LocalPackage | None:
-	package_info = []
 	try:
-		package_info = Pacman.run(f'-Q --info {package}').decode().split('\n')
+		package_info = []
+		for line in Pacman.run(f'-Q --info {package}'):
+			package_info.append(line.decode().strip())
+
 		return _parse_package_output(package_info, LocalPackage)
 	except SysCallError:
 		pass
@@ -115,9 +117,20 @@ def installed_package(package: str) -> LocalPackage | None:
 	return None
 
 
+@lru_cache
+def check_package_upgrade(package: str) -> str | None:
+	try:
+		for line in Pacman.run(f'-Qu {package}'):
+			return line.decode().strip()
+	except SysCallError:
+		debug(f'Failed to check for package upgrades: {package}')
+
+	return None
+
+
 @lru_cache
 def list_available_packages(
-	repositories: tuple[Repository],
+	repositories: tuple[Repository, ...],
 ) -> dict[str, AvailablePackage]:
 	"""
 	Returns a list of all available packages in the database
